==> ckan-2.8.5.tar.gz: ckan-2.8.5/ckan/public/base/i18n/ar.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "ar", 
    "plural-forms": "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    "%(color)sقميص", 
    "%(color)sقميص", 
    "%(color)sقميصان", 
    "%(color)sقمصان", 
    "%(color)s قميص", 
    "%(color)sقمصان"
  ], 
  "%(num)d item": [
    "%(num)d items", 
    "%(num)d مادة", 
    "%(num)d مادة", 
    "%(num)d مادتان", 
    "%(num)d مواد", 
    "%(num)d مادة", 
    "%(num)d مادة"
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    "%(num)d ترجمة ناقصة", 
    "%(num)d ترجمة ناقصة", 
    "%(num)d ترجمتان ناقصتان", 
    "%(num)d ترجمات ناقصة", 
    "%(num)d ترجمات ناقصة", 
    "%(num)d ترجمات ناقصة"
  ], 
  "Add Filter": [
    null, 
    "إضافة فلتر"
  ], 
  "An Error Occurred": [
    null, 
    "حدث خطأ ما"
  ], 
  "An error occured during AJAX request. Could not load view.": [
    null, 
    "حدث خطأ أثناء الطلب التزامني AJAX. تعذر تحميل العرض."
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "هل أنت متأكد أنك تريد تنفيذ هذا الإجراء؟"
  ], 
  "Cancel": [
    null, 
    "إلغاء"
  ], 
  "Confirm": [
    null, 
    "تأكيد"
  ], 
  "Could not load view": [
    null, 
    "تعذر تحميل صيغة العرض"
  ], 
  "DataProxy returned an error": [
    null, 
    "خطأ في وكيل البيانات DataProxy"
  ], 
  "DataStore returned an error": [
    null, 
    "خطأ في مخزن البيانات"
  ], 
  "Edit": [
    null, 
    "تعديل"
  ], 
  "Failed to load data API information": [
    null, 
    "فشل تحميل معلومات بيانات الـ API"
  ], 
  "File": [
    null, 
    "الملف"
  ], 
  "Filters": [
    null, 
    "الفلاتر"
  ], 
  "Follow": [
    null, 
    "تابع"
  ], 
  "Graph": [
    null, 
    "الرسم البياني"
  ], 
  "Grid": [
    null, 
    "جدول"
  ], 
  "Hide": [
    null, 
    "إخفاء"
  ], 
  "Image": [
    null, 
    "صورة"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حرفا", 
    "القيمة المدخلة قصيرة، يجب أن تكون حرفا", 
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حرفين", 
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حروف", 
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حرفا", 
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حرفا"
  ], 
  "Link": [
    null, 
    "رابط"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "رابط عنوان URL على الإنترنت (يمكنك أيضا الربط بـ API)"
  ], 
  "Loading...": [
    null, 
    "تحميل..."
  ], 
  "Map": [
    null, 
    "الخارطة"
  ], 
  "No matches found": [
    null, 
    "لم يتم العثور على نتائج مطابقة"
  ], 
  "Please Confirm Action": [
    null, 
    "يرجى تأكيد الإجراء"
  ], 
  "Remove": [
    null, 
    "إزالة"
  ], 
  "Reorder resources": [
    null, 
    "إعادة ترتيب الموارد"
  ], 
  "Resource uploaded": [
    null, 
    "تم تحميل المورد"
  ], 
  "Save order": [
    null, 
    "حفظ الترتيب"
  ], 
  "Saving...": [
    null, 
    "جار الحفظ ..."
  ], 
  "Select a field": [
    null, 
    "اختيار حقل"
  ], 
  "Show more": [
    null, 
    "إظهار المزيد"
  ], 
  "Start typing…": [
    null, 
    "ابدأ الكتابة..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "هناك تعديلات غير محفوظة في هذا النموذج"
  ], 
  "There is no API data to load for this resource": [
    null, 
    "لا توجد بيانات  API لتحميل لهذا المورد"
  ], 
  "URL": [
    null, 
    "عنوان إنترنت  URL"
  ], 
  "Unable to authenticate upload": [
    null, 
    "لا يمكن المصادقة على التحميل"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "تعذر معالجة بيانات الملف الذي تم تحميله"
  ], 
  "Unable to upload file": [
    null, 
    "لا يمكن تحميل الملف"
  ], 
  "Unfollow": [
    null, 
    "إلغاء المتابعة"
  ], 
  "Upload": [
    null, 
    "تحميل/رفع"
  ], 
  "Upload a file": [
    null, 
    "تحميل ملف"
  ], 
  "Upload a file on your computer": [
    null, 
    "حمّل ملف من جهاز الكمبيوتر الخاص بك"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "أنت الآن تقوم بتحميل ملف. هل أنت متأكد أنك تريد الانتقال وإيقاف هذا التحميل؟"
  ], 
  "You can rearrange the resources by dragging them using the arrow icon. Drag the resource to the right and place it to the desired location on the list. When you are done, click the \"Save order\" -button.": [
    null, 
    "يمكن إعادة ترتيب الموارد بالسحب بواسطة أيقونة السهم على اليمين إلى المكان المرغوب ثم النقر على زر \"حفظ الترتيب\"."
  ], 
  "bar": [
    "bars", 
    "عمود", 
    "عمود", 
    "عمودان", 
    "أعمدة", 
    "أعمدة", 
    "أعمدة"
  ], 
  "error loading view": [
    null, 
    "خطأ في تحميل صيغة العرض"
  ], 
  "foo": [
    null, 
    "فلان"
  ], 
  "hello %(name)s!": [
    null, 
    "مرحبا %(name)s!"
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    "لا %(attr)s ترجمة", 
    "لا %(attr)s ترجمة", 
    "لا %(attr)s ترجمات", 
    "لا %(attr)s ترجمات", 
    "لا %(attr)s ترجمات", 
    "لا %(attr)s ترجمات"
  ], 
  "no translation": [
    "no translations", 
    "لا ترجمة", 
    "لا ترجمة", 
    "لا ترجمة", 
    "لا ترجمات", 
    "لا ترجمات", 
    "لا ترجمات"
  ]
}

==> ckan-2.9.9.tar.gz: ckan-2.9.9/ckan/public/base/i18n/ar.js <==
{
  "": {
    "domain": "ckan",
    "lang": "ar",
    "plural-forms": "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;"
  },
  "Add Filter": [
    null,
    "إضافة فلتر"
  ],
  "An Error Occurred": [
    null,
    "حدث خطأ ما"
  ],
  "An error occured during AJAX request. Could not load view.": [
    null,
    "حدث خطأ أثناء الطلب التزامني AJAX. تعذر تحميل العرض."
  ],
  "Are you sure you want to perform this action?": [
    null,
    "هل أنت متأكد أنك تريد تنفيذ هذا الإجراء؟"
  ],
  "Cancel": [
    null,
    "إلغاء"
  ],
  "Confirm": [
    null,
    "تأكيد"
  ],
  "Could not load view": [
    null,
    "تعذر تحميل صيغة العرض"
  ],
  "DataProxy returned an error": [
    null,
    "خطأ في وكيل البيانات DataProxy"
  ],
  "DataStore returned an error": [
    null,
    "خطأ في مخزن البيانات"
  ],
  "Edit": [
    null,
    "تعديل"
  ],
  "Failed to load data API information": [
    null,
    "فشل تحميل معلومات بيانات الـ API"
  ],
  "File": [
    null,
    "الملف"
  ],
  "Filters": [
    null,
    "الفلاتر"
  ],
  "Follow": [
    null,
    "تابع"
  ],
  "Graph": [
    null,
    "الرسم البياني"
  ],
  "Grid": [
    null,
    "جدول"
  ],
  "Hide": [
    null,
    "إخفاء"
  ],
  "Image": [
    null,
    "صورة"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حرفا",
    "القيمة المدخلة قصيرة، يجب أن تكون حرفا",
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حرفين",
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حروف",
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حرفا",
    "القيمة المدخلة قصيرة، يجب أن تكون %(num)d حرفا"
  ],
  "Link": [
    null,
    "رابط"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "رابط عنوان URL على الإنترنت (يمكنك أيضا الربط بـ API)"
  ],
  "Loading...": [
    null,
    "تحميل..."
  ],
  "Map": [
    null,
    "الخارطة"
  ],
  "No matches found": [
    null,
    "لم يتم العثور على نتائج مطابقة"
  ],
  "Please Confirm Action": [
    null,
    "يرجى تأكيد الإجراء"
  ],
  "Please select the file to upload again": [
    null,
    "يرجى اختيار ملف للتحميل (الرفع) مرة أخرى"
  ],
  "Remove": [
    null,
    "إزالة"
  ],
  "Reorder resources": [
    null,
    "إعادة ترتيب الموارد"
  ],
  "Resource uploaded": [
    null,
    "تم تحميل المورد"
  ],
  "Save order": [
    null,
    "حفظ الترتيب"
  ],
  "Saving...": [
    null,
    "جار الحفظ ..."
  ],
  "Select a field": [
    null,
    "اختيار حقل"
  ],
  "Show more": [
    null,
    "إظهار المزيد"
  ],
  "Start typing…": [
    null,
    "ابدأ الكتابة..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "هناك تعديلات غير محفوظة في هذا النموذج"
  ],
  "There is no API data to load for this resource": [
    null,
    "لا توجد بيانات  API لتحميل لهذا المورد"
  ],
  "URL": [
    null,
    "عنوان إنترنت  URL"
  ],
  "Unable to authenticate upload": [
    null,
    "لا يمكن المصادقة على التحميل"
  ],
  "Unable to get data for uploaded file": [
    null,
    "تعذر معالجة بيانات الملف الذي تم تحميله"
  ],
  "Unable to upload file": [
    null,
    "لا يمكن تحميل الملف"
  ],
  "Unfollow": [
    null,
    "إلغاء المتابعة"
  ],
  "Upload": [
    null,
    "تحميل/رفع"
  ],
  "Upload a file": [
    null,
    "تحميل ملف"
  ],
  "Upload a file on your computer": [
    null,
    "حمّل ملف من جهاز الكمبيوتر الخاص بك"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "أنت الآن تقوم بتحميل ملف. هل أنت متأكد أنك تريد الانتقال وإيقاف هذا التحميل؟"
  ],
  "You can rearrange the resources by dragging them using the arrow icon. Drag the resource to the right and place it to the desired location on the list. When you are done, click the \"Save order\" -button.": [
    null,
    "يمكن إعادة ترتيب الموارد بالسحب بواسطة أيقونة السهم على اليمين إلى المكان المرغوب ثم النقر على زر \"حفظ الترتيب\"."
  ],
  "error loading view": [
    null,
    "خطأ في تحميل صيغة العرض"
  ]
}
